@@ -124,6 +124,7 @@ char *skipPartitionsEntries(char *cPtr)
 char *processHardDrive(char *cPtr, newtComponent editPartition)
 {
   char *cOldPtr;
+  char *FullyBatchMode = "";
   int nMajor, nMinor, nBlocks;
   int nPartNum;
   char szDevice[128];
@@ -152,7 +153,7 @@ char *processHardDrive(char *cPtr, newtComponent editPartition)
 	  memcpy(cFormat, szDevice, strlen(szDevice)); // Device
 	  
 	  SNPRINTF(szFullDevice, "/dev/%s", szDevice);
-	  checkInodeForDevice(szFullDevice);
+	  checkInodeForDevice(szFullDevice, FullyBatchMode);
 	  
 	  if (nBlocks > 1) // a standard device
 	    {
@@ -192,6 +193,7 @@ int fillPartitionList(newtComponent editPartition)
   char cFormat[1024];
   char szTemp[1024];
   char *cPtr;
+  char *FullyBatchMode = "";
   int nLines;
   unsigned int nSize;
   QWORD qwSize;
@@ -253,7 +255,7 @@ int fillPartitionList(newtComponent editPartition)
       
       // detect file system of the hard disk
       SNPRINTF(szFullDevice, "/dev/%s", szDevice);
-      checkInodeForDevice(szFullDevice);
+      checkInodeForDevice(szFullDevice, FullyBatchMode);
       nRes = detectFileSystem(szFullDevice, szTemp);
 
       showDebug(9, "device %s\n", szDevice);     
@@ -508,7 +510,7 @@ int CSavingWindow::create(const char *szDevice, const char *szImageFile, const c
 }
 
 // =======================================================
-void CSavingWindow::showStats(const time_t timeStart, QWORD qwBlockSize, QWORD qwBlocksDone, QWORD qwBlocksTotal)
+void CSavingWindow::showStats(const time_t timeStart, QWORD qwBlockSize, QWORD qwBlocksDone, QWORD qwBlocksTotal, char *szFullyBatchMode)
 {
   BEGIN;
 
@@ -549,6 +551,18 @@ void CSavingWindow::showStats(const time_t timeStart, QWORD qwBlockSize, QWORD q
       
       SNPRINTF(szTemp, i18n("Data copied:.................%s / %s"), formatSize(qwDone, szTemp2), formatSize(qwTotal, szTemp3));
       newtLabelSetText(m_labelStatsSpace, szTemp);
+
+      //option  -B gui=no show stats
+      if ((szFullyBatchMode) && (strlen(szFullyBatchMode)>0))
+      {
+	        fprintf(stderr,"\r\t\t\t\b\b");
+	        SNPRINTF(szTemp, i18n("T:%-s/%-s"), formatTimeNG((DWORD)timeElapsed, szTemp2), formatTimeNG((DWORD)timeRemaining, szTemp3));
+	        fprintf(stderr,"%-s  ",szTemp);
+	        SNPRINTF(szTemp, i18n("R:%s/min"), formatSizeNG(qwBytesPerMin, szTemp2));
+	        fprintf(stderr,"%-s  ",szTemp);
+	        SNPRINTF(szTemp, "P:%3d%%", (int)qwPercent);
+	        fprintf(stderr,"%-s",szTemp);
+      }
     }
 
   newtRefresh();
@@ -572,13 +586,19 @@ void CSavingWindow::destroyForm()
 }
 
 // =======================================================
-void CSavingWindow::showImageFileInfo(char *szImageFile, QWORD qwFreeSpace, QWORD qwImageSize)
+void CSavingWindow::showImageFileInfo(char *szImageFile, QWORD qwFreeSpace, QWORD qwImageSize, char *szFullyBatchMode)
 {
   BEGIN;
 
   char szTemp[2048];
   char szTemp2[2048];
-  
+  char szTemp3[2048];
+  char f1[9];
+  char f2[5];
+  char d[]="./";
+
+  if (strncmp(szImageFile,d,2)==0)
+      szImageFile=szImageFile+strlen(d);
   SNPRINTF(szTemp, i18n("Current image file:..........%s"), szImageFile);
   newtLabelSetText(m_labelImageFile, szTemp);
 
@@ -591,6 +611,32 @@ void CSavingWindow::showImageFileInfo(char *szImageFile, QWORD qwFreeSpace, QWOR
   SNPRINTF (szTemp, i18n("Available space for image:...%s = %llu bytes"), formatSize(qwFreeSpace, szTemp2), qwFreeSpace);
   newtLabelSetText(m_labelFreeSpace, szTemp);
 
+  //option -B gui=no
+  if ((szFullyBatchMode) && (strlen(szFullyBatchMode)>0))
+  {
+
+       if(strrchr(szImageFile,'/'))
+          szImageFile = strrchr(szImageFile,'/')+1;
+
+    if (strlen(szImageFile) > 12)
+    {
+
+      snprintf(f1, 9, i18n("%-s"), szImageFile);
+      snprintf(f2, 5, i18n("%-s"), strrchr(szImageFile,'.'));
+      if (strrchr(szImageFile,'.') != 0)
+      {
+          SNPRINTF(szTemp,"%-s~%-s",f1,f2);
+      }else{
+          snprintf(szTemp, 12, i18n("%-s"), szImageFile);
+      }
+    }else{
+      snprintf(szTemp, 12, i18n("%-s"), szImageFile);
+    }
+
+    SNPRINTF(szTemp3, i18n("%-12s S:%-s "), szTemp, formatSizeNG(qwImageSize, szTemp2));
+    fprintf(stderr,"\r%-s",szTemp3);
+  }  
+
   RETURN;
 }
 
@@ -709,7 +755,7 @@ int CRestoringWindow::create(char *szDevice, char *szImageFile, QWORD qwCurPartS
 }
 
 // =======================================================
-void CRestoringWindow::showStats(const time_t timeStart, QWORD qwBlockSize, QWORD qwBlocksDone, QWORD qwBlocksUsed, QWORD qwBlocksTotal, bool bEraseWithNull)
+void CRestoringWindow::showStats(const time_t timeStart, QWORD qwBlockSize, QWORD qwBlocksDone, QWORD qwBlocksUsed, QWORD qwBlocksTotal, bool bEraseWithNull, char *szFullyBatchMode)
 {
   BEGIN;
 
@@ -764,6 +810,17 @@ void CRestoringWindow::showStats(const time_t timeStart, QWORD qwBlockSize, QWOR
       
       SNPRINTF(szTemp, i18n("Data copied:......................%s / %s"), formatSize(qwDone, szTemp2), formatSize(qwTotal, szTemp3));
       newtLabelSetText(m_labelStatsSpace, szTemp);
+      //option  -B gui=no show stats
+      if ((szFullyBatchMode) && (strlen(szFullyBatchMode)>0))
+      {
+        fprintf(stderr,"\r\t\t\t\b\b");
+        SNPRINTF(szTemp, i18n("T:%-s/%-s"), formatTimeNG((DWORD)timeElapsed, szTemp2), formatTimeNG((DWORD)timeRemaining, szTemp3));
+        fprintf(stderr,"%-s  ",szTemp);
+        SNPRINTF(szTemp, i18n("R:%s/min"), formatSizeNG(qwBytesPerMin, szTemp2));
+        fprintf(stderr,"%-s  ",szTemp);
+        SNPRINTF(szTemp, "P:%3d%%", (int)qwPercent);
+        fprintf(stderr,"%-s",szTemp);
+      }
     }
 
   newtRefresh();
@@ -787,11 +844,19 @@ void CRestoringWindow::destroyForm()
 }
 
 // =======================================================
-void CRestoringWindow::showImageFileInfo(char *szImageFile, int nCompressionMode)
+void CRestoringWindow::showImageFileInfo(char *szImageFile, int nCompressionMode, char *szFullyBatchMode)
 {
   BEGIN;
   
   char szTemp[2048];
+  char szTemp2[2048];
+  char szTemp3[2048];
+  char f1[9];
+  char f2[5];
+  char d[]="./";
+
+  if (strncmp(szImageFile,d,2)==0)
+      szImageFile=szImageFile+strlen(d);
 
   SNPRINTF(szTemp, i18n("Current image file:...............%s"), szImageFile);	
   newtLabelSetText(m_labelImageFile, szTemp);
@@ -802,23 +867,54 @@ void CRestoringWindow::showImageFileInfo(char *szImageFile, int nCompressionMode
 	{
 	case COMPRESS_NONE:
 	  SNPRINTF(szTemp, i18n("Compression level:................None\n"));
+          SNPRINTF(szTemp2, i18n("None"));
 	  break;
 	case COMPRESS_GZIP:
 	  SNPRINTF(szTemp, i18n("Compression level:................gzip"));
+          SNPRINTF(szTemp2, i18n("gzip"));
 	  break;
 	case COMPRESS_BZIP2:
 	  SNPRINTF(szTemp, i18n("Compression level:................bzip2"));
+          SNPRINTF(szTemp2, i18n("bzip2"));
 	  break;
 	case COMPRESS_LZO:
 	  SNPRINTF(szTemp, i18n("Compression level:................lzo"));
+          SNPRINTF(szTemp2, i18n("lzo"));
 	  break;
 	default:
-	  memset(szTemp, 0, sizeof(szTemp));
-	}
-
-      newtLabelSetText(m_labelCompression, szTemp);
+          memset(szTemp2, 0, sizeof(szTemp2));
+        SNPRINTF(szTemp3, i18n("Compression level:................%s"),szTemp2);
+        newtLabelSetText(m_labelCompression, szTemp3);
+       }
     }
 
+  //option -B gui=no
+  if ((szFullyBatchMode) && (strlen(szFullyBatchMode)>0))
+  {
+       if(strrchr(szImageFile,'/'))
+          szImageFile = strrchr(szImageFile,'/')+1;
+
+    if (strlen(szImageFile) > 12)
+    {
+
+      snprintf(f2, 5, i18n("%-s"), strrchr(szImageFile,'.'));
+      snprintf(f1, 9, i18n("%-s"), szImageFile);
+         showDebug(3,"f1=%s, f2=%s",f1,f2);
+      if (strrchr(szImageFile,'.') != 0)
+      {
+          SNPRINTF(szTemp,"%-s~%-s",f1,f2);
+      }else{
+          snprintf(szTemp, 12, i18n("%-s"), szImageFile);
+      }
+    }else{
+      snprintf(szTemp, 12, i18n("%-s"), szImageFile);
+    }
+
+    SNPRINTF(szTemp3, i18n("%-12s %-s "), szTemp, szTemp2);
+    fprintf(stderr,"\r%-s",szTemp3);
+  }
+
+
   RETURN;
 }
 
