@@ -103,6 +103,8 @@ static struct option const long_options[] =
 };
 #endif
 
+static char finish_last_countfile_lock[]="/tmp/partimageXXXXXX.lock";
+static char finish_last_countfile[]="/tmp/partimageXXXXXX";
 static char optstring[]="z:oV:ecmdhf:s:p:bwg:vynSMa:iU:P:XB:";
 FILE * g_fDebug; // debug file
 FILE * g_fLocalDebug; // debug file
@@ -176,7 +178,7 @@ int main(int argc, char *argv[])
   options.bSync = OPTIONS_DEFAULT_SYNC;
   options.dwDebugLevel = DEFAULT_DEBUG_LEVEL; // defined by configure.in
   strncpy(options.szServerName, OPTIONS_DEFAULT_SERVERNAME, MAX_HOSTNAMESIZE);
-  strncpy(options.szAutoMount, OPTIONS_DEFAULT_AUTOMOUNT, MAXPATHLEN);
+  strncpy(options.szFullyBatchMode, OPTIONS_DEFAULT_FULLYBATCHMODE, 2048);
   strncpy(options.szUserName, OPTIONS_DEFAULT_USERNAME, MAX_USERNAMELEN);
   strncpy(options.szPassWord, OPTIONS_DEFAULT_PASSWORD, MAX_PASSWORDLEN);
   *(options.szFullyBatchMode) = 0;
@@ -683,8 +685,13 @@ int main(int argc, char *argv[])
       break;
       
     default: // exit
+      if (options.bBatchMode)
+             fprintf(stderr,"\n\n");
+
       if (options.bSync)
         {
+          if (options.bBatchMode)
+               fprintf(stderr,"\n\n");
           g_interface -> StatusLine(i18n("commiting buffer cache to disk."));
 	  sync();
         }
@@ -698,6 +705,8 @@ int main(int argc, char *argv[])
   // update the disk IO
   if (options.bSync)
     {
+      if (options.bBatchMode)
+             fprintf(stderr,"\n\n");
       g_interface -> StatusLine(i18n("commiting buffer cache to disk."));
       sync();
     }
@@ -781,6 +790,13 @@ int main(int argc, char *argv[])
       else if (options.dwFinish == FINISH_REBOOT)
 	{
 	  showDebug(1, "option FINISH_REBOOT\n");
+          if (options.bSimulateMode)
+                formatOperationSucessMsg(szTemp, sizeof(szTemp), i18n("Simulation"));
+           else
+               formatOperationSucessMsg(szTemp, sizeof(szTemp), i18n("Operation"));
+          if (nChoice != OPERATION_IMGINFO)
+            g_interface->msgBoxOk(i18n("Success"), szTemp);
+
 	  delete g_interface; 
 	  nRes = system("/sbin/shutdown -r now");
           nRes = system("/sbin/reboot");
@@ -797,66 +813,83 @@ int main(int argc, char *argv[])
       else if (options.dwFinish == FINISH_LAST)
 	{
 	  showDebug(1, "option FINISH_LAST\n");
-	  int nLockFile;
-	  FILE * nCountFile;
+	  int fd_lock, fd_countfile;
+ 	  FILE *fCountFile;
+	  FILE *fLockFile;
 	  int nValue, nRetries;
 
 	  nRetries = 5;
-          do {
-	    nLockFile = open(FINISH_LAST_COUNTFILE_LOCK, O_CREAT|O_EXCL,
-               O_RDONLY);
-	    if (nLockFile == -1)
+          do 
+	  {
+	    if ((fd_lock = mkstemp(finish_last_countfile_lock)) == -1)
 	      {
-                --nRetries;
-		sleep(2);
+		delete g_interface;
+		fprintf(stderr, i18n("Error: Cannot create lock for countfile"));
+		return EXIT_FAILURE;
 	      }
-	  } while (nLockFile == -1 && nRetries);
-	  if (!nRetries)
+	    fLockFile = fdopen(fd_lock, "r");
+	    if (fLockFile == NULL)
+ 	      {
+                 --nRetries;
+ 		sleep(2);
+ 	      }
+	  } while (fLockFile == NULL && nRetries);
+ 	  if (!nRetries)
+ 	    {
+    	      delete g_interface;
+ 	      fprintf(stderr, i18n("Error: Cannot count remaining partimages"));
+ 	      return EXIT_SUCCESS;
+ 	    }
+	  if ((fd_countfile = mkstemp(finish_last_countfile)) == -1)
+	    {
+	      delete g_interface;
+	      fprintf(stderr, i18n("Error: Cannot create countfile"));
+	      return EXIT_FAILURE;
+	    }
+          fCountFile = fdopen(fd_countfile, "r");
+	  if (fCountFile == NULL)
 	    {
     	      delete g_interface; 
 	      fprintf(stderr, i18n("Error: Cannot count remaining partimages"));
 	      return EXIT_SUCCESS;
 	    }
-          nCountFile = fopen(FINISH_LAST_COUNTFILE, "r");
-	  if (nCountFile == NULL)
-	    {
-    	      delete g_interface; 
-	      fprintf(stderr, i18n("Error: Cannot count remaining partimages"));
-	      return EXIT_SUCCESS;
-	    }
-	  fscanf(nCountFile, "%d\n", &nValue);
+	  fscanf(fCountFile, "%d\n", &nValue);
 	  showDebug(1, "RESTANT: %d\n", nValue);
 	  if (nValue <= 1)
-	    { // we are the last running partimage -> shutdown
-	      delete g_interface; 
-	      fclose(nCountFile);
-	      close(nLockFile);
-	      unlink(FINISH_LAST_COUNTFILE_LOCK);
-	      unlink(FINISH_LAST_COUNTFILE);
-//	      nRes = system("/sbin/shutdown -r now");
-//              nRes = system("/sbin/reboot");
-// if we reach this point, it's because shutdown failed
+ 	    { // we are the last running partimage -> shutdown
+ 	      delete g_interface; 
+ 	      fclose(fCountFile);
+	      fclose(fLockFile);
+	      close(fd_lock);
+	      close(fd_countfile);
+	      unlink(finish_last_countfile_lock);
+	      unlink(finish_last_countfile);
+ //	      nRes = system("/sbin/shutdown -r now");
+ //              nRes = system("/sbin/reboot");
+ // if we reach this point, it's because shutdown failed
 	      fprintf(stderr, i18n("DEBUG: reboot the computer"));
 	      return EXIT_SUCCESS;
 	    }
 	  else
 	    {
               --nValue;
-	      fclose(nCountFile);
-              nCountFile = fopen(FINISH_LAST_COUNTFILE, "w");
-	      if (nCountFile == NULL)
+	      fclose(fCountFile);
+              fCountFile = fdopen(fd_countfile, "w");
+	      if (fCountFile == NULL)
 	        {
     	          delete g_interface; 
 	          fprintf(stderr, i18n("Error: Cannot count remaining "
                      "partimages"));
 	          return EXIT_SUCCESS;
 	        }
-	      fprintf(nCountFile, "%d\n", nValue);
-	      fclose(nCountFile);
-	      close(nLockFile);
-	      unlink(FINISH_LAST_COUNTFILE_LOCK);
-    	      delete g_interface; 
-	      return EXIT_SUCCESS;
+	      fprintf(fCountFile, "%d\n", nValue);
+	      fclose(fCountFile);
+	      fclose(fLockFile);
+	      close(fd_lock);
+	      close(fd_countfile);
+	      unlink(finish_last_countfile_lock);
+     	      delete g_interface; 
+ 	      return EXIT_SUCCESS;
 	    }
         }
     }
@@ -1086,9 +1119,9 @@ void formatOperationSucessMsg(char *szMsg, int nMaxLen, char *szOperation)
   qwBytesPerMin = (QWORD) (((float)g_qwCopiedBytesCount) / fMinElapsed);
   
   snprintf(szMsg, nMaxLen, i18n("%s  successfully finished:\n\n"
-				"Time elapsed:...%s\n"
-				"Speed:..........%s/min\n"
-				"Data copied:....%s"),
+                                "Time elapsed: %s\n"
+                                "Speed: %s/min\n"
+                                "Data copied: %s"),
 	   szOperation,
 	   formatTime((DWORD)timeElapsed, szTemp1),
 	   formatSize(qwBytesPerMin, szTemp2),
