@@ -355,6 +355,8 @@ void savePartition(char *szDevice, char *szImageName, //, char *szFileSystem,
   image.set_szPath(aux);
   
   //if (options->dwSplitMode == SPLIT_AUTO)
+  if ((strncmp(szImageName, "stdout", 6) == 0) || (strncmp(szImageName, "STDOUT", 6) == 0))
+	  options->qwSplitSize = 0;
   if (!options->qwSplitSize)
     {
       SNPRINTF(aux, "%s", szImageName); *(aux+MAXPATHLEN-1)='\0';
@@ -373,10 +375,10 @@ void savePartition(char *szDevice, char *szImageName, //, char *szFileSystem,
       guiOpt.create(image.get_szImageFilename(), *options);
     }
 
-  g_interface -> StatusLine(i18n("initializing the operation. Please wait..."));
+    g_interface -> StatusLine(i18n("initializing the operation."));
   
   // ----------- system checks
-  nRes = systemChecks(szDevice, options->bFailIfMounted);
+  nRes = systemChecks(szDevice, options->bFailIfMounted, options->szFullyBatchMode);
   if (nRes == -1)
     THROW( ERR_FSCHK);
   
@@ -513,7 +515,20 @@ void savePartition(char *szDevice, char *szImageName, //, char *szFileSystem,
   //image.set_dwCurrentVolumeSize(0L);
   image.set_dwVolumeNumber(0L);
   //image.set_qwIdentificator(headMain.qwIdentificator);
-  
+
+  // gui = no
+  if (strlen(options->szFullyBatchMode)>0)
+  {
+                 showDebug(3,"szFullyBatchMode=%s\n, len=%d",options->szFullyBatchMode,strlen(options->szFullyBatchMode));
+    fprintf(stderr,"partimage: status: Partimage: %s\n", headMain.szVersion);
+    if (options->dwCompression == 0)
+      fprintf(stderr,"partimage: status: Image type: NONE\n");
+    else if (options->dwCompression == 1) +      fprintf(stderr,"partimage: status: Image type: GZIP\n");
+    else if (options->dwCompression == 2)
+      fprintf(stderr,"partimage: status: Image type: BZIP2\n");
+    else if (options->dwCompression == 3)
+      fprintf(stderr,"partimage: status: Image type: LZO\n");
+  }  
   try { image.write(&headMain, sizeof(CMainHeader), true); }
   catch ( CExceptions * excep )
     {
@@ -713,7 +728,7 @@ void restorePartition(char *szDevice, char *szImageName, COptions *options)
   g_interface -> StatusLine(i18n("initializing the operation"));
   
   // ----------- system checks
-  nRes = systemChecks(szDevice, options->bFailIfMounted);
+  nRes = systemChecks(szDevice, options->bFailIfMounted, options->szFullyBatchMode);
   if (nRes == -1)
     THROW( ERR_FSCHK);
   
@@ -903,6 +918,22 @@ void restorePartition(char *szDevice, char *szImageName, COptions *options)
   try { lockFile(fileno(fDeviceFile), szDevice); }
   catch ( CExceptions * excep )
     { throw excep; }
+  // gui = no
+  if (strlen(options->szFullyBatchMode)>0)
+  {
+          showDebug(3,"szFullyBatchMode=%s\n, len=%d",options->szFullyBatchMode,strlen(options->szFullyBatchMode));
+    options->dwCompression = (DWORD) image.getCompressionLevelForImage(szImageName);
+    fprintf(stderr,"partimage: status: Partimage: %s\n", headMain.szVersion);
+    if (options->dwCompression == 0)
+      fprintf(stderr,"partimage: status: Image type: NONE\n");
+    else if (options->dwCompression == 1)
+      fprintf(stderr,"partimage: status: Image type: GZIP\n");
+    else if (options->dwCompression == 2)
+      fprintf(stderr,"partimage: status: Image type: BZIP2\n");
+    else if (options->dwCompression == 3)
+      fprintf(stderr,"partimage: status: Image type: LZO\n");
+  }
+  g_interface -> StatusLine(i18n("Restoring partition from the image file..."));
 
 
   // --------- initialize info window -------------
@@ -918,7 +949,7 @@ void restorePartition(char *szDevice, char *szImageName, COptions *options)
   
   // ----------- print informations about image file
   //guiInfo.showPartitionInfos(options->dwCompression, headMain.szOriginalDevice, headMain.szFileSystem, headMain.dateCreate, headMain.qwPartSize);
-  guiInfo.showImageFileInfo(szImageName, -1);
+//  guiInfo.showImageFileInfo(szImageName, -1, options->szFullyBatchMode);
 
   // -*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-
   CFSBase *FS = NULL; 
@@ -1183,6 +1214,7 @@ void showDebugOptions(COptions *options)
 	    "options.bBackupMBR = %d\n" 
 	    "options.bSimulateMode = %d\n" 
 	    "options.szAutoMount = %s\n" 
+            "options.szFullyBatchMode = %s\n"
 	    "============= end OPTIONS =====================\n\n\n",
 	    (int) options->bOverwrite, 
 	    //options->dwSplitMode,
@@ -1192,7 +1224,7 @@ void showDebugOptions(COptions *options)
 	    options->dwFinish, options->szServerName, 
 	    options->dwServerPort, (int) options->bBatchMode, (int)options->bSplitWait,
 	    (int)options->bSync, (int)options->bUseSSL, options->dwDebugLevel, 
-	    (int)options->bBackupMBR, (int)options->bSimulateMode, options->szAutoMount);
+            (int)options->bBackupMBR, (int)options->bSimulateMode, options->szAutoMount, options->szFullyBatchMode);
 }
 
 // =======================================================
@@ -1372,7 +1404,7 @@ int showUfsDisklabel(char *szDevice)
   FILE *fStream;
   char cBoot[512];
   CUFSDiskLabel dl;
-  int i, j;
+  int i=0, j;
   int nRes;
   CUFSPartition part;
   char letter='a';
@@ -1629,7 +1661,7 @@ int getMajorMinor(char *szDevice, int *nMajor, int *nMinor)
 }
 
 // =======================================================
-int checkInodeForDevice(char *szDevice) // NEW FUNCTION
+int checkInodeForDevice(char *szDevice, char *szFullyBatchMode) // NEW FUNCTION
 {
   int nRes;
   struct stat fStat;
@@ -1643,11 +1675,13 @@ int checkInodeForDevice(char *szDevice) // NEW FUNCTION
   nRes = access(szDevice, F_OK);
   if (nRes == -1)
     {
-      nRes = g_interface->msgBoxYesNo(i18n("inode missing"), i18n("%s inode doesn't exists. Partimage can create it for you. You can also use the manual mknod "
+      if(strlen(szFullyBatchMode)<=0)
+      {
+          nRes = g_interface->msgBoxYesNo(i18n("inode missing"), i18n("%s inode doesn't exists. Partimage can create it for you. You can also use the manual mknod "
 								  "command. Do you want this inode to be created for you now ?"), szDevice);
-      if (nRes == MSGBOX_NO)
-	  RETURN_int(-1);
-
+          if (nRes == MSGBOX_NO)
+	      RETURN_int(-1);
+      }
       nRes = getMajorMinor(szDevice, &nMajor, &nMinor);
       if (nRes == -1)
 	RETURN_int(-1);
@@ -1871,13 +1905,13 @@ char *decodePartitionEntry(char *cPtr, int *nMajor, int *nMinor,
 }
 
 // =======================================================
-int systemChecks(char *szDevice, bool bFailIfMounted)
+int systemChecks(char *szDevice, bool bFailIfMounted, char *szFullyBatchMode)
 {
   char szMountPoint[1024];
   int nRes;
   
   // ----------- check for inode
-  nRes = checkInodeForDevice(szDevice);
+  nRes = checkInodeForDevice(szDevice, szFullyBatchMode);
   if (nRes == -1)
     RETURN_int(-1);	
   
@@ -1952,7 +1986,6 @@ int checkOptions(COptions options, char *szDevice, char *szImageFile)
 	  g_interface->msgBoxError(i18n("The third argument [%s] must be a valid regular file (not a directory, a symlink, ...)"), szImageFile);	
 	  RETURN_int(-1);
 	}
-
     }
 
   return 0;
